
******************
Command-line tools
******************

shelephant_dump
---------------

.. argparse::
    :module: shelephant.cli
    :func: _shelephant_dump_parser
    :prog: shelephant_dump

shelephant_hostinfo
-------------------

.. argparse::
    :module: shelephant.cli
    :func: _shelephant_hostinfo_parser
    :prog: shelephant_hostinfo

shelephant_cp
-------------

.. argparse::
    :module: shelephant.cli
    :func: _shelephant_cp_parser
    :prog: shelephant_cp

shelephant_mv
-------------

.. argparse::
    :module: shelephant.cli
    :func: _shelephant_mv_parser
    :prog: shelephant_mv

shelephant_rm
-------------

.. argparse::
    :module: shelephant.cli
    :func: _shelephant_rm_parser
    :prog: shelephant_rm

shelephant_diff
---------------

.. argparse::
    :module: shelephant.cli
    :func: _shelephant_diff_parser
    :prog: shelephant_diff

shelephant_parse
----------------

.. argparse::
    :module: shelephant.cli
    :func: _shelephant_parse_parser
    :prog: shelephant_parse
